@@ -15,27 +15,23 @@ struct kino_FieldSpec {
     KINO_FIELDSPEC_VTABLE *_;
     KINO_OBJ_MEMBER_VARS;
     float          boost;
-    kino_bool_t    indexed;
-    kino_bool_t    stored;
-    kino_bool_t    analyzed;
-    kino_bool_t    vectorized;
-    kino_bool_t    binary;
-    kino_bool_t    compressed;
-    kino_bool_t    store_field_boost;
-    kino_bool_t    store_freq;
-    kino_bool_t    store_position;
-    kino_bool_t    store_pos_boost;
+    chy_bool_t     indexed;
+    chy_bool_t     stored;
+    chy_bool_t     analyzed;
+    chy_bool_t     vectorized;
+    chy_bool_t     binary;
+    chy_bool_t     compressed;
+    struct kino_Posting *posting;
 };
 
 /* Constructor.
  */
-KINO_FUNCTION(
 kino_FieldSpec*
-kino_FSpec_new(const char *class_name));
+kino_FSpec_new(const char *class_name);
 
-KINO_METHOD("Kino_FSpec_Destroy",
 void
-kino_FSpec_destroy(kino_FieldSpec *self));
+kino_FSpec_destroy(kino_FieldSpec *self);
+KINO_METHOD("Kino_FSpec_Destroy");
 
 KINO_END_CLASS
 
