@@ -5,15 +5,12 @@ package KinoSearch::Index::DocVector;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
-BEGIN {
-    __PACKAGE__->init_instance_vars(
-        # members
-        field_strings => {},
-        field_vectors => {},
-    );
+our %instance_vars = (
+    # members
+    field_strings => {},
+    field_vectors => {},
+);
 
-}
-our %instance_vars;
 use KinoSearch::Index::TermVector;
 
 sub term_vector {
